@@ -3,11 +3,10 @@ from datetime import datetime
 from typing import Optional
 from typing import Type
 
-from bs4.element import Tag  # type: ignore
-
 from .connection import join_url
 from .connection import root
 from .parse import BeautifulSoup
+from .parse import Tag
 from .parse import check_page_raise
 from .parse import parse_user_page
 from .parse import parse_user_tag
